{% extends "bee_django_user/base.html" %}

{% block content %}
    <h3>后台管理</h3>

    <div><a href="{% url 'bee_django_crm:index' %}">crm</a></div>
    <div><a href="{% url 'bee_django_user:index' %}">user</a></div>
    <div><a href="{% url 'bee_django_course:index' %}">course</a></div>
    <div><a href="{% url 'bee_django_course_simple:index' %}">course_simple</a></div>
    <div><a href="{% url 'bee_django_coin:index' %}">coin</a></div>
    <div><a href="{% url 'bee_django_exam:index' %}">exam</a></div>
    <div><a href="{% url 'bee_django_mission:index' %}">mission</a></div>
    <div><a href="{% url 'bee_django_message:index' %}">message</a></div>
    <div><a href="{% url 'bee_django_social_feed:index' %}">feed</a></div>
    <div><a href="{% url 'bee_django_report:index' %}">reprot</a></div>



{% endblock %}