# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-22 08:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0017_userprofile_is_pause'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserSN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.IntegerField(unique=True, verbose_name='\u8d77')),
                ('end', models.IntegerField(unique=True, verbose_name='\u8d77')),
                ('is_used', models.BooleanField(default=False, verbose_name='\u662f\u5426\u6b63\u5728\u4f7f\u7528')),
            ],
        ),
        migrations.AlterModelOptions(
            name='userprofile',
            options={'ordering': ['-created_at'], 'permissions': (('can_manage', '\u53ef\u4ee5\u8bbf\u95ee\u540e\u53f0\u7ba1\u7406'), ('can_change_user_group', '\u53ef\u4ee5\u4fee\u6539\u7528\u6237\u7ec4'), ('can_change_user_sn', '\u53ef\u4ee5\u4fee\u6539sn\u53f7'), ('reset_user_password', '\u53ef\u4ee5\u91cd\u7f6e\u7528\u6237\u5bc6\u7801'), ('view_all_users', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u7528\u6237'), ('view_manage_users', '\u53ef\u4ee5\u67e5\u770b\u7ba1\u7406\u7684\u7528\u6237'), ('view_teach_users', '\u53ef\u4ee5\u67e5\u770b\u6559\u7684\u7528\u6237'))},
        ),
        migrations.AddField(
            model_name='userprofile',
            name='sn',
            field=models.IntegerField(null=True, unique=True, verbose_name='\u7edf\u4e00\u7f26\u5ba2\u53f7'),
        ),
    ]
