# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-06-30 09:58
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0025_auto_20190630_1540'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userprofile',
            options={'ordering': ['-created_at'], 'permissions': (('can_manage', '\u53ef\u4ee5\u8bbf\u95ee\u540e\u53f0\u7ba1\u7406'), ('can_change_user_group', '\u53ef\u4ee5\u4fee\u6539\u7528\u6237\u7ec4'), ('can_change_user_sn', '\u53ef\u4ee5\u4fee\u6539sn\u53f7'), ('can_change_user_status', '\u53ef\u4ee5\u4fee\u6539\u7528\u6237\u72b6\u6001'), ('can_change_user_parent', '\u53ef\u4ee5\u4fee\u6539\u7528\u6237\u7684\u5bb6\u957f\u52a9\u6559'), ('reset_user_password', '\u53ef\u4ee5\u91cd\u7f6e\u7528\u6237\u5bc6\u7801'), ('view_all_users', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u7528\u6237'), ('view_manage_users', '\u53ef\u4ee5\u67e5\u770b\u7ba1\u7406\u7684\u7528\u6237'), ('view_teach_users', '\u53ef\u4ee5\u67e5\u770b\u6559\u7684\u7528\u6237'), ('view_child_users', '\u53ef\u4ee5\u67e5\u770b\u4eb2\u5b50\u7528\u6237'))},
        ),
    ]
