# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-08 03:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0016_userprofile_avatar'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='is_pause',
            field=models.BooleanField(default=False, verbose_name='\u6682\u505c'),
        ),
    ]
