# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-31 06:34
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0013_userprofile_is_leave'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userprofile',
            name='is_leave',
        ),
    ]
